@@ -1,6 +1,7 @@
 import numpy as np
 import xarray as xr
 import datetime
+import pandas as pd
 
 from .DMTGlobals import DMTGlobals
 
@@ -233,7 +234,7 @@ def process_psds(particle_ds, hk_ds, config, deltaSize=0.005, num_bins=199, avg_
         scat_parts = np.logical_and(scatter_accept, parts_time)
         incan_parts = np.logical_and(incand_accept, parts_time)
         ConcIncanCycle = OneOfEvery * np.sum(incan_parts)
-        ConcTotalCycle = OneOfEvery * (np.sum(incan_parts) + np.sum(scat_parts))
+        ConcTotalCycle = OneOfEvery * np.sum(np.logical_or(incan_parts,scat_parts))
         ConcScatCycle = OneOfEvery * np.sum(scat_parts)
         ConcScatSatCycle = OneOfEvery * np.sum(np.logical_and(scat_parts, incan_sat))
         ConcIncanScatCycle = OneOfEvery * np.sum(np.logical_and(scat_parts, incan_parts))
@@ -284,8 +285,8 @@ def process_psds(particle_ds, hk_ds, config, deltaSize=0.005, num_bins=199, avg_
     MassIncand2total.attrs["long_name"] = "Incandescence mass concentration (total)"
     MassIncand2total.attrs["standard_name"] = "mass_concentration"
     MassIncand2total.attrs["units"] = "ng m-3"
-    base_time = datetime.datetime(1904, 1, 1).timestamp()
-    time = np.array([datetime.datetime.fromtimestamp(x + base_time) for x in time_bins[:-1]])
+    base_time = pd.Timestamp('1904-01-01')
+    time = np.array([(base_time + datetime.timedelta(seconds=x)).to_datetime64() for x in time_bins[:-1]])
     time = xr.DataArray(time, dims=('time'))
     time_wave = xr.DataArray(time_bins[:-1], dims=('time'))
     time_wave.attrs["long_name"] = "Time"
@@ -320,6 +321,11 @@ def process_psds(particle_ds, hk_ds, config, deltaSize=0.005, num_bins=199, avg_
     MassIncand.attrs["long_name"] = "Incandescence mass concentration"
     MassIncand.attrs["standard_name"] = "mass_concentration"
     MassIncand.attrs["units"] = "ng m-3"
+    
+    MassIncand2 = xr.DataArray(MassIncand2, dims=('time'))
+    MassIncand2.attrs["long_name"] = "Incandescence mass concentration"
+    MassIncand2.attrs["standard_name"] = "mass_concentration"
+    MassIncand2.attrs["units"] = "ng m-3"
 
     MassIncand2Sat = xr.DataArray(MassIncand2Sat, dims=('time'))
     MassIncand2Sat.attrs["long_name"] = "Incandescence mass concentration (saturated)"
